@@ -113,7 +113,7 @@ class Data_inegrator:
                 epoch += 1
                 # Do an epoch on the training set.
                 for patient_train_batch in self.xy_train_dataloader:
-                    field0_batch, field1_batch = patient_train_batch['FIELD0'], patient_train_batch['FIELD1']
+                    field0_batch, field1_batch = patient_train_batch['FIELD0'].squeeze(), patient_train_batch['FIELD1'].squeeze()
                     train_step_function(field0_batch, field1_batch)
 
                 # Do validation
@@ -121,20 +121,20 @@ class Data_inegrator:
                 with torch.no_grad():
                     full_vae.eval()
                     for validation_patient_batch in self.xy_validation_dataloader:
-                        field0_batch, field1_batch = validation_patient_batch['FIELD0'], validation_patient_batch[
-                            'FIELD1']
+                        field0_batch, field1_batch = validation_patient_batch['FIELD0'].squeeze(), validation_patient_batch[
+                            'FIELD1'].squeeze()
                         forward_dict = full_vae(field0_batch, field1_batch)
                         # Computes reconstruction loss and according to it decide whether to stop.
                         loss_dict = full_vae.loss_function(forward_dict)
-                        total_validation_loss_per_epoch += loss_dict['xvae_loss']['Reconstruction_Loss'] + \
+                        total_validation_loss_per_epoch += float(loss_dict['xvae_loss']['Reconstruction_Loss'] + \
                                                            loss_dict['xyvae_loss']['Reconstruction_Loss'] + \
-                                                           loss_dict['yvae_loss']['Reconstruction_Loss']
+                                                           loss_dict['yvae_loss']['Reconstruction_Loss'])
                     # Compute the average validation sample loss.
                     average_validation_sample_loss = total_validation_loss_per_epoch / len(self.xy_validation_dataset)
                     # If the loss achieved on the validation is the smallest until so far, save the model.
                     if average_validation_sample_loss < best_model_loss:
                         torch.save(full_vae, os.path.join(self.results_path, 'best_model.pt'))
-                        best_model_loss = float(average_validation_sample_loss)
+                        best_model_loss = average_validation_sample_loss
                     # keep tracking of the validation loss in every epoch.
                     average_validation_sample_loss_per_epoch.append(average_validation_sample_loss)
                     stop = early_stopping(average_validation_sample_loss_per_epoch, patience=self.patience,
